51214e13eabd4d1610106195fe69a16f9759e3cf
max
  Mon Jan 8 06:28:56 2024 -0800
changes after code review, refs #32836

diff --git src/product/installer/browserSetup.sh src/product/installer/browserSetup.sh
index 2af110f..aa4887d 100644
--- src/product/installer/browserSetup.sh
+++ src/product/installer/browserSetup.sh
@@ -34,32 +34,34 @@
 # ---- GLOBAL DEFAULT SETTINGS ----
 
 # Directory where CGI-BIN and htdocs are downloaded to.
 # this is the main runtime directory of the genome browser. It contains
 # CGI binaries, the config file (hg.conf), temporary ("trash") files, downloaded pieces of big files
 # ("udcCache") and various other runtime data needed for the browser
 APACHEDIR=/usr/local/apache
 
 # apache document root, for html documents
 HTDOCDIR=$APACHEDIR/htdocs
 # apache CGI-bin directory
 CGIBINDIR=$APACHEDIR/cgi-bin
 # directory for temporary files
 TRASHDIR=$APACHEDIR/trash
 
-# mysql data directory 
-# for most genome annotation data
+# Mysql data directory 
+# Yes we only support mariaDB anymore, but the variables will keep their names
+# Below please assume that mariadb is meant when mysql is written.
+# For most genome annotation data
 # (all non-mysql data is stored in /gbdb)
 MYSQLDIR=/var/lib/mysql
 
 # mysql admin binary, different path on OSX
 MYSQLADMIN=mysqladmin
 
 # mysql user account, different on OSX
 MYSQLUSER=mysql
 
 # mysql client command, will be adapted on OSX
 MYSQL=mysql
 
 # flag whether a mysql root password should be set
 # the root password is left empty on OSX, as mysql
 # there is not listening to a port
@@ -776,39 +778,39 @@
 
     # this triggers an error if rpmforge is not installed
     # but if rpmforge is installed, we need the option
     # psxy is not that important, we just skip it for now
     #yum -y install GMT hdf5 --disablerepo=rpmforge
     
     if [ -f /etc/init.d/iptables ]; then
        echo2 Opening port 80 for incoming connections to Apache
        waitKey
        iptables -I INPUT 1 -p tcp --dport 80 -j ACCEPT
        iptables -I INPUT 1 -p tcp --dport 443 -j ACCEPT
        service iptables save
        service iptables restart
     fi
     
     # MYSQL INSTALL ON REDHAT
 
     # centos7 provides only a package called mariadb-server
     # Mysql 8 does not allow copying MYISAM files anymore into the DB. 
     # -> we cannot support Mysql 8 anymore
     if yum list mariadb-server 2> /dev/null ; then
         MYSQLPKG=mariadb-server
     else
-        echo2 Cannot find a mysql-server package in the current yum repositories
+        echo2 Cannot find a mariadb-server package in the current yum repositories
         exit 100
     fi
     
@@ -776,39 +778,39 @@
     fi
     
-    # MYSQL INSTALL ON REDHAT
+    # MARIADB INSTALL ON REDHAT
 
     # centos7 provides only a package called mariadb-server
     # even mariadb packages currently call their main wrapper /usr/bin/mysqld_safe
     if [ ! -f /usr/bin/mysqld_safe ]; then
         echo2 
         echo2 Installing the Mysql or MariaDB server and make it start at boot.
         waitKey
 
         moveAwayMyCnf
         yum -y install $MYSQLPKG
     
         # Fedora 20 names the package mysql-server but it actually contains mariadb
         MYSQLD=mysqld
         MYSQLVER=`mysql --version`